
-- ensure this operation is atomic (in case some eejit pulls the plug on you)
START TRANSACTION;
SET @Machine_ID = 29;
SET @Aircon_Port  = '/dev/serial/by-path/pci-0000:00:15.0-usb-0:3:1.0-port0';
SET @Chiller_Port = '/dev/serial/by-path/pci-0000:00:15.0-usb-0:5:1.0-port0';

-- Interfaces table does not have space in the Serial_Port column to store by-path values
ALTER TABLE Interfaces MODIFY COLUMN Serial_Port VARCHAR(256);

-- Alter the interface the A/C is on to use its by-path id.
UPDATE Interfaces SET Serial_Port = @Aircon_Port WHERE Serial_Port = '/dev/ttyUSB0';

-- Create the interface and save its ID to a variable.
SET @Iface_ID = UUID();

INSERT Into Interfaces (Interface_ID, Iface_Type, Serial_Port) VALUES (@Iface_ID, 3, @Chiller_Port);

-- Create the module and save its ID to a variable
INSERT INTO Modules (Module_ID, Machine_ID, Description, Module_Address, Interface_ID) VALUES (UUID(), @Machine_ID, 'Chiller Module', 1, @Iface_ID);
SELECT Module_ID INTO @Mod_ID FROM Modules WHERE Description = 'Chiller Module';

-- Install the Sensors
INSERT INTO Sensors (Sensor_ID, Module_ID, Description, Register_Address, Data_Type, ReadPriority) VALUES (UUID(),  @Mod_ID, 'Control Mode', 1000, 0, 2);
INSERT INTO Sensors (Sensor_ID, Module_ID, Description, Register_Address, Data_Type, ReadPriority) VALUES (UUID(),  @Mod_ID, 'Control', 1001, 0, 2);
INSERT INTO Sensors (Sensor_ID, Module_ID, Description, Register_Address, Data_Type, ReadPriority) VALUES (UUID(),  @Mod_ID, 'RPM Set', 1002, 0, 2);
INSERT INTO Sensors (Sensor_ID, Module_ID, Description, Register_Address, Data_Type, ReadPriority) VALUES (UUID(),  @Mod_ID, 'Direction', 1003, 0, -1);
INSERT INTO Sensors (Sensor_ID, Module_ID, Description, Register_Address, Data_Type, ReadPriority) VALUES (UUID(),  @Mod_ID, 'Speed', 2000, 0, 2);
INSERT INTO Sensors (Sensor_ID, Module_ID, Description, Register_Address, Data_Type, ReadPriority) VALUES (UUID(),  @Mod_ID, 'Fault 1', 2001, 0, 1);
INSERT INTO Sensors (Sensor_ID, Module_ID, Description, Register_Address, Data_Type, ReadPriority) VALUES (UUID(),  @Mod_ID, 'Fault2', 2002, 0, 1);
INSERT INTO Sensors (Sensor_ID, Module_ID, Description, Register_Address, Data_Type, ReadPriority) VALUES (UUID(),  @Mod_ID, 'Warning1', 2003, 0, 1);
INSERT INTO Sensors (Sensor_ID, Module_ID, Description, Register_Address, Data_Type, ReadPriority) VALUES (UUID(),  @Mod_ID, 'Warning 2', 2004, 0, 1);
INSERT INTO Sensors (Sensor_ID, Module_ID, Description, Register_Address, Data_Type, ReadPriority) VALUES (UUID(),  @Mod_ID, 'Bus Voltage', 2005, 0, 1);
INSERT INTO Sensors (Sensor_ID, Module_ID, Description, Register_Address, Data_Type, ReadPriority) VALUES (UUID(),  @Mod_ID, 'Output Current', 2006, 0, 1);
INSERT INTO Sensors (Sensor_ID, Module_ID, Description, Register_Address, Data_Type, ReadPriority) VALUES (UUID(),  @Mod_ID, 'Ambient Temp', 2007, 0, 1);
INSERT INTO Sensors (Sensor_ID, Module_ID, Description, Register_Address, Data_Type, ReadPriority) VALUES (UUID(),  @Mod_ID, 'Module Temp', 2008, 0, 1);

-- write the changes to the DB.
COMMIT;
